/*  frameworks.c - main function and threads for frameworks.
 
    (Derived from:
    qcam.c - The frontend to Gqcam, a GTK based QuickPict clone.)

    Copyright (C) 1999 Cory Lueninghoener (cluenin1@bigred.unl.edu)
    Copyright (C) 2003 Pat Mahoney <pat@polycrystal.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

#include "common.h"

/* global vars */
gboolean fwks_quit = FALSE;

int main(int argc, char *argv[])
{
    struct Interface *interface;
    static struct Camera camera;
    int i;
    gboolean force_read = FALSE;
    GString *device_file = NULL;

    g_thread_init(NULL);
    gtk_init(&argc, &argv);
    gdk_rgb_init();
    gdk_threads_init();

    /* To command line args: "-r" forces read(), and "device_name" is
     * the filename of the video device (defaults to /dev/video). */
    if (argc > 1) {
        for (i=1; i<argc; i++) {
            if (strcmp("-r", argv[i]) == 0) {
                force_read = TRUE;
            } else {
                device_file = g_string_new(argv[i]);
            }
        }
    }
    if (device_file == NULL)
        device_file = g_string_new("/dev/video");

    /* Initialize the camera. It should start a thread that reads from
     * the camera repeatedly and then return. */
    frameworks_camera_initialize(&camera, device_file, force_read);

    /* Initialize the interface.  It should start any threads it
     * needs, then run gtk_main() itself and never return until
     * program exit */
    interface = frameworks_interface_run(&camera);

    exit(0);
}
